@@ -4,7 +4,7 @@ import datetime
 import decimal
 import sys
 from ctypes import *
-from ctypes import _Pointer
+from ctypes import _Pointer, Array as _CArrayType
 from _ctypes import CopyComPointer
 from ctypes.wintypes import DWORD, LONG, UINT, VARIANT_BOOL, WCHAR, WORD
 from typing import Any, ClassVar, Dict, List, Optional, TYPE_CHECKING, Type
@@ -16,9 +16,11 @@ import comtypes.patcher
 import comtypes
 
 if TYPE_CHECKING:
+    from ctypes import _CArgObject
     from comtypes import hints  # type: ignore
     from comtypes import _safearray
 else:
+    _CArgObject = type(byref(c_int()))
     try:
         from comtypes import _safearray
     except (ImportError, AttributeError):
@@ -50,7 +52,6 @@ INVOKEKIND = tagINVOKEKIND
 # helpers
 IID_NULL = GUID()
 riid_null = byref(IID_NULL)
-_byref_type = type(byref(c_int()))
 
 # 30. December 1899, midnight.  For VT_DATE.
 _com_null_date = datetime.datetime(1899, 12, 30, 0, 0, 0)
@@ -129,7 +130,7 @@ class tagDEC(Structure):
         ("Lo64", c_ulonglong),
     ]
 
-    def as_decimal(self):
+    def as_decimal(self) -> decimal.Decimal:
         """Convert a tagDEC struct to Decimal.
 
         See http://msdn.microsoft.com/en-us/library/cc234586.aspx for the tagDEC
@@ -137,12 +138,8 @@ class tagDEC(Structure):
 
         """
         digits = (self.Hi32 << 64) + self.Lo64
-        decimal_str = "{0}{1}e-{2}".format(
-            "-" if self.sign else "",
-            digits,
-            self.scale,
-        )
-        return decimal.Decimal(decimal_str)
+        sign = "-" if self.sign else ""
+        return decimal.Decimal(f"{sign}{digits}e-{self.scale}")
 
 
 DECIMAL = tagDEC
@@ -382,7 +379,7 @@ class tagVARIANT(Structure):
         elif isinstance(value, c_uint64):
             self.vt = VT_UI8
             self._.VT_UI8 = value
-        elif isinstance(value, _byref_type):
+        elif isinstance(value, _CArgObject):
             ref = value._obj
             self._.c_void_p = addressof(ref)
             self.__keepref = value
@@ -609,9 +606,6 @@ v.vt = VT_ERROR
 v._.VT_I4 = 0x80020004
 del v
 
-_carg_obj = type(byref(c_int()))
-from ctypes import Array as _CArrayType
-
 
 @comtypes.patcher.Patch(POINTER(VARIANT))
 class _(object):
@@ -626,7 +620,7 @@ class _(object):
         if isinstance(arg, POINTER(VARIANT)):
             return arg
         # accept byref(VARIANT) instance
-        if isinstance(arg, _carg_obj) and isinstance(arg._obj, VARIANT):
+        if isinstance(arg, _CArgObject) and isinstance(arg._obj, VARIANT):
             return arg
         # accept VARIANT instance
         if isinstance(arg, VARIANT):
@@ -750,7 +744,7 @@ EXCEPINFO = tagEXCEPINFO
 
 class tagDISPPARAMS(Structure):
     if TYPE_CHECKING:
-        rgvarg: Array[VARIANT]
+        rgvarg: _CArrayType[VARIANT]
         rgdispidNamedArgs: _Pointer[DISPID]
         cArgs: int
         cNamedArgs: int
